# KEGScraper

> The ultimate KEGS webscraping module

KEGScraper is a Python package which simplifies any interaction with [KEGS](https://kegs.org.uk/) and any
services used by KEGS.

The module currently supports the given services:
- [The main website](https://kegs.org.uk/)
- [Bromcom](https://bromcomvle.com/)
- [KEGS IT](https://it.kegs.org.uk/)
- [KEGSnet (moodle)](https://vle.kegs.org.uk/)
- [The Oliver library system](https://kegs.oliverasp.co.uk/)

This module is a **work in progress** and is not complete. Many more features will be added.
